@@ -111,8 +111,10 @@ class py23_mp_queue(MP_Queue):
         self.size = SharedCounter(0)
 
     def put(self, *args, **kwargs):
-        self.size.increment(1)
+        local_size = self.size
         super(py23_mp_queue, self).put(*args, **kwargs)
+        local_size.increment(1)
+        self.size.increment(1)
 
     def get(self, *args, **kwargs):
         self.size.increment(-1)
@@ -588,10 +590,11 @@ class TaskMgr(object):
 
             except Empty:
                 state = "__EMPTY__"
-            except Exception as e:
+
+            except Exception as ee:
                 tb_str = "".join(tb.format_exception(*(sys.exc_info())))
                 print("ERROR:")
-                print(e, tb_str)
+                print(ee, tb_str)
 
             if stats.log_time:
                 if self.log_level >= 0:
